/* 
   main_hy2.cc
   example main program using a Hybrid_NMSearch.
   
   Liz Dolan, 1999 and Anne Shepherd, 8/2000 at
   The College of William and Mary, Williamsburg, Virginia,
   under advisor Dr. Virginia Torczon   
   
   to compile use:
   g++ -g -Wall main_hy2.cc objective.cc DirectSearch.cc SimplexSearch.cc NMSearch.cc Hybrid_NMSearch.cc PatternSearch.cc EdHJSearch.cc  -lm -o main_hy2

*/

#include "objective.h"    
#include "Hybrid_NMSearch.h" 
#include <iostream>              // for cout
#include "vec.h"

using namespace std;

int main(void)
{    
  long n = 4;                      // number of variables (dimension of
                                   //             the search)
  // starting point for x.  This is the starting point used by Nelder
  // and Mead
  double startVals[] = {3, -1, 0, 1};       
  double startstep = 1.0;          // starting step length
  double endstep = 10e-8;          // ending step length
  double end_Cstep = 10e-8;
  //extern long deltacount;
  
  Vector<double> Sminimum(n);      // to store the minimum point later

  /* we'll initialize an n-entry Vector whose value is startVal,
   * and use it as our starting point.
   */
  Vector<double>minVec(n, startVals);
  cout << "Starting point is: " << minVec << endl;
        
  
  /* now construct a Search object  
   * in order to use the long constructor, we need to 
   * send a NULL in as the last parameter, because we won't be
   * using that parameter here.
   */ 
  Hybrid_NMSearch HNM(n, minVec, 0.5, 1.0, 0.5, 2.0, startstep,
              endstep, end_Cstep, powell, NULL);

  double SMinVal;
  long Scalls;
  HNM.SetMaxCalls(-1);
  HNM.ChooseRegularSimplex();
  cout << "\ndelta = " << HNM.GetDelta() << endl;
  // HNM.PrintDesign();

  //HNM.Set_Stop_on_std();
  /* start searching */
  HNM.BeginSearch();

  
  HNM.GetMinPoint(Sminimum);
  HNM.GetMinVal(SMinVal);
  Scalls = HNM.GetFunctionCalls();
  
  cout << "\nMinimum point found: " << Sminimum;
  cout << "Value: \n" << SMinVal <<  " in ";
  cout << Scalls << " function calls.\n" << endl<< "\n\n";
  cout << "\ndelta = " << HNM.GetDelta() << endl;
  // cout << "\ndeltacount = " << deltacount << endl;
  
  return 0;

}//main



